@@ -6,6 +6,9 @@ class ShoppingListItem(mongo.EmbeddedDocument):
     item = mongo.ReferenceField('Ingredient', required=True)
     supermarketSection = mongo.StringField()
     listPosition = mongo.IntField(min_value=0)
+    
+    quantity = mongo.FloatField(min_value=0)
+    unitOfMeasure = mongo.StringField(max_length=10)
 
 class ShoppingList(mongo.Document):
     name = mongo.StringField()
@@ -14,7 +17,8 @@ class ShoppingList(mongo.Document):
     owner = mongo.ReferenceField('User', required=True)
 
     meta = {
-        'collection' : 'shopping_lists'
+        'collection' : 'shopping_lists',
+        'strict' : False #TODO remove when use base_model as parent model
     }
 
     def __repr__(self):
