@@ -13,10 +13,8 @@ def create_module(app, **kwargs):
     from .controllers import auth_blueprint
     app.register_blueprint(auth_blueprint)
 
-def authenticate(username, password):
-    user = User.objects(
-        username__exact=username
-    ).first()
+def authenticate(email, password):
+    user = get_user_by_email(email)
     
     if not user:
         return None
@@ -27,5 +25,12 @@ def authenticate(username, password):
     
     return user
 
+def get_user_by_email(email):
+    user = User.objects(
+        email__exact=email
+    ).first()
+    
+    return user
+
 def encode_password(password: str) -> str:
     return bcrypt.generate_password_hash(str(password))
\ No newline at end of file
